@@ -8,9 +8,10 @@
 
 from .data_model import KISAO_ALGORITHM_MAP
 from biosimulators_utils.combine.exec import exec_sedml_docs_in_archive
+from biosimulators_utils.config import get_config
 from biosimulators_utils.log.data_model import CombineArchiveLog, TaskLog  # noqa: F401
 from biosimulators_utils.viz.data_model import VizFormat  # noqa: F401
-from biosimulators_utils.report.data_model import ReportFormat, VariableResults  # noqa: F401
+from biosimulators_utils.report.data_model import ReportFormat, VariableResults, SedDocumentResults  # noqa: F401
 from biosimulators_utils.sedml.data_model import (Task, ModelLanguage, UniformTimeCourseSimulation,  # noqa: F401
                                                   Variable, Symbol)
 from biosimulators_utils.utils.core import validate_str_value, parse_value
@@ -25,18 +26,18 @@ from kisao.utils import get_preferred_substitute_algorithm_by_ids
 from kisao.warnings import AlgorithmSubstitutedWarning
 import functools
 import os
-cwd = os.getcwd()  # because PySCeS changes the working directory
-import pysces  # noqa: E402
-os.chdir(cwd)
-import tempfile  # noqa: E402
+import pysces
+import tempfile
 
 
 __all__ = ['exec_sedml_docs_in_combine_archive', 'exec_sed_task']
 
 
 def exec_sedml_docs_in_combine_archive(archive_filename, out_dir,
+                                       return_results=False,
                                        report_formats=None, plot_formats=None,
-                                       bundle_outputs=None, keep_individual_outputs=None):
+                                       bundle_outputs=None, keep_individual_outputs=None,
+                                       raise_exceptions=True):
     """ Execute the SED tasks defined in a COMBINE/OMEX archive and save the outputs
 
     Args:
@@ -48,21 +49,28 @@ def exec_sedml_docs_in_combine_archive(archive_filename, out_dir,
             * HDF5: directory in which to save a single HDF5 file (``{ out_dir }/reports.h5``),
               with reports at keys ``{ relative-path-to-SED-ML-file-within-archive }/{ report.id }`` within the HDF5 file
 
+        return_results (:obj:`bool`, optional): whether to return the result of each output of each SED-ML file
         report_formats (:obj:`list` of :obj:`ReportFormat`, optional): report format (e.g., csv or h5)
         plot_formats (:obj:`list` of :obj:`VizFormat`, optional): report format (e.g., pdf)
         bundle_outputs (:obj:`bool`, optional): if :obj:`True`, bundle outputs into archives for reports and plots
         keep_individual_outputs (:obj:`bool`, optional): if :obj:`True`, keep individual output files
+        raise_exceptions (:obj:`bool`, optional): whether to raise exceptions
 
     Returns:
-        :obj:`CombineArchiveLog`: log
+        :obj:`tuple`:
+
+            * :obj:`SedDocumentResults`: results
+            * :obj:`CombineArchiveLog`: log
     """
     sed_doc_executer = functools.partial(exec_sed_doc, exec_sed_task)
     return exec_sedml_docs_in_archive(sed_doc_executer, archive_filename, out_dir,
                                       apply_xml_model_changes=True,
+                                      return_results=return_results,
                                       report_formats=report_formats,
                                       plot_formats=plot_formats,
                                       bundle_outputs=bundle_outputs,
-                                      keep_individual_outputs=keep_individual_outputs)
+                                      keep_individual_outputs=keep_individual_outputs,
+                                      raise_exceptions=raise_exceptions)
 
 
 def exec_sed_task(task, variables, log=None):
@@ -79,25 +87,29 @@ def exec_sed_task(task, variables, log=None):
             :obj:`VariableResults`: results of variables
             :obj:`TaskLog`: log
     '''
+    config = get_config()
+
     log = log or TaskLog()
 
     model = task.model
     sim = task.simulation
 
-    raise_errors_warnings(validation.validate_task(task),
-                          error_summary='Task `{}` is invalid.'.format(task.id))
-    raise_errors_warnings(validation.validate_model_language(task.model.language, ModelLanguage.SBML),
-                          error_summary='Language for model `{}` is not supported.'.format(model.id))
-    raise_errors_warnings(validation.validate_model_change_types(task.model.changes, ()),
-                          error_summary='Changes for model `{}` are not supported.'.format(model.id))
-    raise_errors_warnings(*validation.validate_model_changes(task.model),
-                          error_summary='Changes for model `{}` are invalid.'.format(model.id))
-    raise_errors_warnings(validation.validate_simulation_type(task.simulation, (UniformTimeCourseSimulation, )),
-                          error_summary='{} `{}` is not supported.'.format(sim.__class__.__name__, sim.id))
-    raise_errors_warnings(*validation.validate_simulation(task.simulation),
-                          error_summary='Simulation `{}` is invalid.'.format(sim.id))
-    raise_errors_warnings(*validation.validate_data_generator_variables(variables),
-                          error_summary='Data generator variables for task `{}` are invalid.'.format(task.id))
+    if config.VALIDATE_SEDML:
+        raise_errors_warnings(validation.validate_task(task),
+                              error_summary='Task `{}` is invalid.'.format(task.id))
+        raise_errors_warnings(validation.validate_model_language(task.model.language, ModelLanguage.SBML),
+                              error_summary='Language for model `{}` is not supported.'.format(model.id))
+        raise_errors_warnings(validation.validate_model_change_types(task.model.changes, ()),
+                              error_summary='Changes for model `{}` are not supported.'.format(model.id))
+        raise_errors_warnings(*validation.validate_model_changes(task.model),
+                              error_summary='Changes for model `{}` are invalid.'.format(model.id))
+        raise_errors_warnings(validation.validate_simulation_type(task.simulation, (UniformTimeCourseSimulation, )),
+                              error_summary='{} `{}` is not supported.'.format(sim.__class__.__name__, sim.id))
+        raise_errors_warnings(*validation.validate_simulation(task.simulation),
+                              error_summary='Simulation `{}` is invalid.'.format(sim.id))
+        raise_errors_warnings(*validation.validate_data_generator_variables(variables),
+                              error_summary='Data generator variables for task `{}` are invalid.'.format(task.id))
+
     target_x_paths_to_sbml_ids = validation.validate_variable_xpaths(variables, task.model.source, attr='id')
 
     # Get the current working directory because PySCeS opaquely changes it
